.. include:: ../README.rst
   :start-after: This is used inside the doc to recover the start of the short text for contribution
   :end-before: This is used inside the doc to recover the end of the short text for contribution
